
# Slot: extensions


a tag/text tuple attached to an arbitrary element

URI: [linkml:extensions](https://w3id.org/linkml/extensions)


## Domain and Range

[Extensible](Extensible.md) &#8594;  <sub>0..\*</sub> [Extension](Extension.md)

## Parents


## Children

 *  [annotations](annotations.md)

## Used by

 * [Annotation](Annotation.md)
 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [Element](Element.md)
 * [EnumDefinition](EnumDefinition.md)
 * [Extensible](Extensible.md)
 * [Extension](Extension.md)
 * [PermissibleValue](PermissibleValue.md)
 * [SchemaDefinition](SchemaDefinition.md)
 * [SlotDefinition](SlotDefinition.md)
 * [SubsetDefinition](SubsetDefinition.md)
 * [TypeDefinition](TypeDefinition.md)
 * [UniqueKey](UniqueKey.md)
